@@ -53,10 +53,8 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 #include "symbol.h"
 #include "target.h"
 #include "where.h"
-#if FFECOM_targetCURRENT == FFECOM_targetGCC
 #include "flags.h"
 #include "toplev.h"
-#endif
 
 /* Externals defined here. */
 
@@ -80,7 +78,6 @@ bool ffe_is_globals_ = TRUE;
 bool ffe_is_init_local_zero_ = FFETARGET_defaultIS_INIT_LOCAL_ZERO;
 bool ffe_is_mainprog_;		/* TRUE if current prog unit known to be
 				   main. */
-bool ffe_is_null_version_ = FALSE;
 bool ffe_is_onetrip_ = FALSE;
 bool ffe_is_silent_ = TRUE;
 bool ffe_is_typeless_boz_ = FALSE;
@@ -175,8 +172,6 @@ ffe_decode_option (argc, argv)
 	  ffe_set_is_version (TRUE);
 	  ffe_set_is_do_internal_checks (TRUE);
 	}
-      else if (strcmp (&opt[2], "null-version") == 0)
-	ffe_set_is_null_version (TRUE);
       else if (strcmp (&opt[2], "f66") == 0)
 	{
 	  ffe_set_is_onetrip (TRUE);
